from typing import Optional
import os

class SiftDevConfig:
    def __init__(
        self,
        service_name: str = "python-app",
        service_instance_id: Optional[str] = None,
        otlp_endpoint: Optional[str] = None,
        sift_dev_ingest_key: Optional[str] = None,
        env: str = "",
        batch_delay_millis: int = 5000,
    ):
        self.service_name = service_name
        self.service_instance_id = service_instance_id
        self.otlp_endpoint = otlp_endpoint if otlp_endpoint is not None else os.getenv("OTLP_ENDPOINT")
        self.sift_dev_ingest_key = sift_dev_ingest_key if sift_dev_ingest_key is not None else os.getenv("SIFT_DEV_INGEST_KEY")
        self.env = env or os.getenv("ENV", "unspecified")
        self.batch_delay_millis = batch_delay_millis

_default_config: Optional[SiftDevConfig] = None

def configure(config: SiftDevConfig):
    global _default_config
    _default_config = config

def get_config() -> SiftDevConfig:
    global _default_config
    if _default_config is None:
        # Create a default configuration, using no OTLP configuration.
        _default_config = SiftDevConfig()
    return _default_config 